The module associated with the @/${zenoh_id:*}/remote-plugin/ format, it contains:
Format, a zero-sized type that represents your format.formatter(), a function that constructs aFormatterspecialized for your format:- for every spec in your format,
Formatterwill have a method named after the spec’sidthat lets you set a value for that field of your format. These methods will returnResult<&mut Formatter, FormatError>.
- for every spec in your format,
parse(target: &keyexpr) -> ZResult<Parsed<'_>>will parse the provided key expression according to your format. Just likeKeFormat::parse, parsing is lazy: each field will match the smallest subsection of yourtargetthat is included in its pattern.- like
Formatter,Parsedwill have a method named after each spec’sidthat returns&keyexpr; except for specs whose pattern was**, these will return anOption<&keyexpr>, whereNonesignifies that the pattern was matched by an empty list of chunks.
- like
Structs
- Format
- The
@/${zenoh_id:*}/remote-plugin/format, as a zero-sized-type. - Formatter
- And instance of a formatter for
@/${zenoh_id:*}/remote-plugin/. - Parsed